use Test::More tests => 1;

BEGIN {
	use_ok( 'DBIx::Class::InflateColumn::Object::Enum' );
}

diag( "Testing DBIx::Class::InflateColumn::Object::Enum $DBIx::Class::InflateColumn::Object::Enum::VERSION, Perl $], $^X" );
